@@ -1,7 +1,7 @@
 /*
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
- *  Copyright 2004 Novell, Inc. (www.novell.com)
+ *  Copyright 2004-2005 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -47,6 +47,41 @@ enum {
   E_ICALSHARE_TIMEOUT_WEEKS
 };
 
+static GtkWidget * e_webcal_label_new (const gchar * str) {
+  GtkWidget * label;
+
+  label = gtk_label_new (str);
+  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+
+  return label;
+}
+
+static void e_webcal_label_size_allocate_cb (GtkWidget *widget,
+					     GtkAllocation *allocation,
+					     gpointer user_data) {
+  gint width, height;
+  GtkWidget *label;
+
+  label = user_data;
+
+  gtk_widget_get_size_request (label, &width, &height);
+
+  if (allocation->width > 1 &&
+      allocation->width != (width + label->allocation.x)) {
+    gtk_widget_set_size_request (label,
+				 allocation->width - label->allocation.x,
+				 -1);
+    gtk_container_check_resize (GTK_CONTAINER (widget));
+  }
+}
+
+static void e_webcal_label_handle_resize (GtkWidget * label,
+					  GtkWidget * container) {
+  g_signal_connect (G_OBJECT (container), "size-allocate",
+		    G_CALLBACK (e_webcal_label_size_allocate_cb), label);
+}
+
 static void e_webcal_icon_theme_changed (GnomeIconTheme * theme,
 					 EIcalShareDialog * dialog) {
   gchar * icofile;
@@ -390,22 +425,23 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
 
   /* Box for Name and Description */
   vbox = gtk_vbox_new (FALSE, 12);
-  gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
   /* Name */
   mrkname = g_strdup_printf ("<b>%s</b>", name ? name : tmpname);
-  label = gtk_label_new (mrkname);
-  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+  label = e_webcal_label_new (mrkname);
+  e_webcal_label_handle_resize (label, vbox);
   g_free (mrkname);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
   /* Description */
-  label = gtk_label_new (desc ? desc : _("No Description"));
+  label = e_webcal_label_new (desc ? desc : _("No Description"));
+  e_webcal_label_handle_resize (label, vbox);
+  gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
